@@ -74,21 +74,21 @@ def send_stocks(url, body, token):
 
 
 def post_prices(url, price: Price, token) -> PriceResponse:
-    logger.debug("POST: {}".format(url))
     try:
         headers = {'Content-type': 'application/json',
                    'Accept': 'text/html',
                    'access-token': token}
 
         json_prices = jsonpickle.encode(price, unpicklable=False)
-        response = requests.post(url, json=json.loads(json_prices), headers=headers)
+        logger.info(f'{url} - {json_prices}')
+        response = requests.put(url, json=json.loads(json_prices), headers=headers)
 
         obj = jsonpickle.decode(response.content)
         return PriceResponse(**obj)
 
     except Exception as ex:
-        logger.error(str(ex), exc_info=True)
-        return PriceResponse([price.codigo_erp], 3, str(ex), '')
+        logger.error(str(ex))
+        return PriceResponse([price.codigo_erp], 3, str(ex), '', '')
 
 
 def get_order_queue(url: str, token: str, status: str, limit: int) -> list[Queue]:
@@ -149,10 +149,10 @@ def put_client_erp_code(url: str, token: str, body: dict) -> bool:
         return False
 
 
-def put_protocol_orders(url: str, token: str, body: list) -> bool:
+def put_protocol_orders(order_id) -> bool:
+    url = src.client_data.get('url_api') + f'/pedido/integrado/{order_id}'
     try:
-        data = jsonpickle.encode(body, unpicklable=False)
-        response = requests.put(url, data=json.loads(data), headers={'Accept': 'application/json', 'access-token': token})
+        response = requests.put(url, headers={'Accept': 'application/json', 'access-token': src.client_data.get('token_api')})
         if response.ok:
             return True
         else:
