@@ -10,8 +10,8 @@ class CatalogoResponse:
 
 
 class PriceResponse:
-    def __init__(self, codigo_erp, Status: int, Message: str, Protocolo: str):
+    def __init__(self, codigo_erp, Status: int, Message: str, protocolo: str, loja: str):
         self.codigo_erp = codigo_erp
         self.status = Status
         self.message = Message
-        self.protocolo = Protocolo
+        self.protocolo = protocolo
